UnnamedStruct13 class final

The information from updating contact.

Inheritance
Implemented types
Available extensions

Constructors

UnnamedStruct13()

Properties

acc_id ↔ int
getter/setter pair
address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
code ↔ int
< SIP status code received.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
is_register ↔ int
< SIP Register if PJ_TRUE.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited