UnnamedStruct25 class final

Media descriptor line ("m=" line)

Inheritance
Implemented types
Available extensions

Constructors

UnnamedStruct25()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
fmt ↔ Array<pj_str_t>
< Media formats.
getter/setter pair
fmt_count ↔ int
< Number of formats.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
media ↔ pj_str_t
< Media type ("audio", "video")
getter/setter pair
port ↔ int
< Port number.
getter/setter pair
port_count ↔ int
< Port count, used only when >2
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transport ↔ pj_str_t
< Transport ("RTP/AVP")
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited