UnnamedStruct32 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedStruct32()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
end ↔ pj_time_val
< Validity end
getter/setter pair
gmt ↔ int
< Flag if validity date/time use GMT
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ pj_time_val
< Validity start
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited