UnnamedUnion7 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedUnion7()

Properties

address → Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
data ↔ Pointer<Void>
< Generic data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rdata ↔ Pointer<pjsip_rx_data>
< The incoming message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int
< Transport error status.
getter/setter pair
tdata ↔ Pointer<pjsip_tx_data>
< The outgoing message.
getter/setter pair
timer ↔ Pointer<pj_timer_entry>
< The timer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited