output_vol property
Output volume setting, in percent. This setting is optional, and will only be used if PJMEDIA_AUD_DEV_CAP_OUTPUT_VOLUME_SETTING is set in the flags.
Implementation
@ffi.UnsignedInt()
external int output_vol;
Output volume setting, in percent. This setting is optional, and will only be used if PJMEDIA_AUD_DEV_CAP_OUTPUT_VOLUME_SETTING is set in the flags.
@ffi.UnsignedInt()
external int output_vol;