print_body property

Pointer<NativeFunction<Int Function(Pointer<pjsip_msg_body> msg_body, Pointer<Char> buf, pj_size_t size)>> print_body
getter/setter pair

Pointer to function to print this message body. Application must set a proper function here when sending outgoing message.

@param msg_body This structure itself. @param buf The buffer. @param size The buffer size.

@return The length of the string printed, or -1 if there is not enough space in the buffer to print the whole message body.

Implementation

external ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<pjsip_msg_body> msg_body,
            ffi.Pointer<ffi.Char> buf, pj_size_t size)>> print_body;