hangup_forked_call property

  1. @Int()
int hangup_forked_call
getter/setter pair

Disconnect other call legs when more than one 2xx responses for outgoing INVITE are received due to forking. Currently the library is not able to handle simultaneous forked media, so disconnecting the other call legs is necessary.

With this setting enabled, the library will handle only one of the connected call leg, and the other connected call legs will be disconnected.

Default: PJ_TRUE (only disable this setting for testing purposes).

Implementation

@pj_bool_t()
external int hangup_forked_call;