max_calls property

  1. @UnsignedInt()
int max_calls
getter/setter pair

Maximum calls to support (default: 4). The value specified here must be smaller than or equal to the compile time maximum settings PJSUA_MAX_CALLS. To increase this limit, the library must be recompiled with new PJSUA_MAX_CALLS value.

Implementation

@ffi.UnsignedInt()
external int max_calls;