has_ioqueue property

  1. @Int()
int has_ioqueue
getter/setter pair

Specify whether the media manager should manage its own ioqueue for the RTP/RTCP sockets. If yes, ioqueue will be created and at least one worker thread will be created too. If no, the RTP/RTCP sockets will share the same ioqueue as SIP sockets, and no worker thread is needed.

Normally application would say yes here, unless it wants to run everything from a single thread.

Implementation

@pj_bool_t()
external int has_ioqueue;