qos_params property

pj_qos_params qos_params
getter/setter pair

Set the low level QoS parameters to the transport. This is a lower level operation than setting the \a qos_type field and may not be supported on all platforms.

For TLS transport, this field will be ignored, the low level QoS parameters can be set via tls_setting.

Default is QoS not set.

Implementation

external pj_qos_params qos_params;