pjsua_tpfactory_register method
Register transport factory that has been created by application. This function is useful if application wants to implement custom SIP transport and use it with pjsua.
@param tf Transport factory instance. @param p_id Optional pointer to receive transport ID.
@return PJ_SUCCESS on success, or the appropriate error code.
Implementation
int pjsua_tpfactory_register(
ffi.Pointer<pjsip_tpfactory> tf,
ffi.Pointer<pjsua_transport_id> p_id,
) {
return _pjsua_tpfactory_register(
tf,
p_id,
);
}